@@ -735,7 +735,6 @@ void TouchGestureArea::resyncCachedTouchPoints()
     bool added = false;
     bool ended = false;
     bool moved = false;
-    bool wantsDrag = false;
 
     // list of deletes
     QMutableHashIterator<int, GestureTouchPoint*> removeIter(m_cachedTouchPoints);
@@ -765,10 +764,6 @@ void TouchGestureArea::resyncCachedTouchPoints()
         }
     }
 
-    if (wantsDrag && !dragging()) {
-        setDragging(true);
-    }
-
     if (ended) {
         if (m_cachedTouchPoints.isEmpty()) {
             if (!dragging()) Q_EMIT clicked();
