@@ -282,13 +282,10 @@ Indicator::Ptr IndicatorsManager::indicator(const QString& indicator_name)
     // convergence:
     // 1) enable session indicator
     // 2) enable keyboard indicator
-    // 3) on a PC, switch the battery/power indicator to desktop mode,
-    //    can't control brightness for now and phone-on-desktop broken (FIXME)
     //
     // The rest of the indicators respect their default profile (which is "phone", even on desktop PCs)
     if ((new_indicator->identifier() == QStringLiteral("indicator-session"))
-            || new_indicator->identifier() == QStringLiteral("indicator-keyboard")
-            || (new_indicator->identifier() == QStringLiteral("indicator-power") && m_platform.isPC())) {
+            || new_indicator->identifier() == QStringLiteral("indicator-keyboard")) {
         new_indicator->setProfile(QString(m_profile).replace(QStringLiteral("phone"), QStringLiteral("desktop")));
     } else {
         new_indicator->setProfile(m_profile);
