@@ -1,5 +1,5 @@
 /*
- * Copyright 2013-2014 Canonical Ltd.
+ * Copyright 2013-2016 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -12,20 +12,18 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *      Michael Zanetti <michael.zanetti@canonical.com>
  */
 
 #include "launchermodel.h"
 #include "launcheritem.h"
 #include "gsettings.h"
-#include "desktopfilehandler.h"
 #include "dbusinterface.h"
 #include "asadapter.h"
+#include "ualwrapper.h"
 
 #include <unity/shell/application/ApplicationInfoInterface.h>
 #include <unity/shell/application/MirSurfaceListInterface.h>
+#include <unity/shell/application/MirSurfaceInterface.h>
 
 #include <QDesktopServices>
 #include <QDebug>
@@ -157,16 +155,16 @@ void LauncherModel::pin(const QString &appId, int index)
             index = m_list.count();
         }
 
-        DesktopFileHandler desktopFile(appId);
-        if (!desktopFile.isValid()) {
-            qWarning() << "Can't pin this application, there is no .desktop file available.";
+        UalWrapper::AppInfo appInfo = UalWrapper::getApplicationInfo(appId);
+        if (!appInfo.valid) {
+            qWarning() << "Can't pin application, appId not found:" << appId;
             return;
         }
 
         beginInsertRows(QModelIndex(), index, index);
         LauncherItem *item = new LauncherItem(appId,
-                                              desktopFile.displayName(),
-                                              desktopFile.icon(),
+                                              appInfo.name,
+                                              appInfo.icon,
                                               this);
         item->setPinned(true);
         m_list.insert(index, item);
@@ -201,12 +199,26 @@ void LauncherModel::quickListActionInvoked(const QString &appId, int actionIndex
             } else {
                 pin(appId);
             }
-        } else if (actionId == QLatin1String("launch_item")) {
+        } else if (actionId == QStringLiteral("launch_item")) {
             QDesktopServices::openUrl(getUrlForAppId(appId));
-        } else if (actionId == QLatin1String("stop_item")) { // Quit
+        } else if (actionId == QStringLiteral("stop_item")) { // Quit
             if (m_appManager) {
                 m_appManager->stopApplication(appId);
             }
+        } else if (actionId.startsWith(QStringLiteral("surface_"))){
+            ApplicationInfoInterface *appInfo = m_appManager->findApplication(appId);
+            if (appInfo) {
+                for (int i = 0; i < appInfo->surfaceList()->count(); ++i) {
+                    MirSurfaceInterface *iface = appInfo->surfaceList()->get(i);
+                    QString id = actionId;
+                    id.remove(QRegExp("^surface_"));
+                    if (id == iface->persistentId()) {
+                        iface->activate();
+                    }
+                }
+            } else {
+                qWarning() << "App for" << appId << "not found in launcher. Cannot invoke quicklist action";
+            }
         // Nope, we don't know this action, let the backend forward it to the application
         } else {
             // TODO: forward quicklist action to app, possibly via m_dbusIface
@@ -217,7 +229,6 @@ void LauncherModel::quickListActionInvoked(const QString &appId, int actionIndex
 void LauncherModel::setUser(const QString &username)
 {
     Q_UNUSED(username)
-    qWarning() << "This backend doesn't support multiple users";
 }
 
 QString LauncherModel::getUrlForAppId(const QString &appId) const
@@ -380,11 +391,11 @@ void LauncherModel::countVisibleChanged(const QString &appId, bool countVisible)
         }
     } else {
         // Need to create a new LauncherItem and show the highlight
-        DesktopFileHandler desktopFile(appId);
-        if (countVisible && desktopFile.isValid()) {
+        UalWrapper::AppInfo appInfo = UalWrapper::getApplicationInfo(appId);
+        if (countVisible && appInfo.valid) {
             LauncherItem *item = new LauncherItem(appId,
-                                                  desktopFile.displayName(),
-                                                  desktopFile.icon(),
+                                                  appInfo.name,
+                                                  appInfo.icon,
                                                   this);
             item->setCountVisible(true);
             beginInsertRows(QModelIndex(), m_list.count(), m_list.count());
@@ -400,28 +411,28 @@ void LauncherModel::refresh()
     // First walk through all the existing items and see if we need to remove something
     QList<LauncherItem*> toBeRemoved;
     Q_FOREACH (LauncherItem* item, m_list) {
-        DesktopFileHandler desktopFile(item->appId());
-        if (!desktopFile.isValid()) {
-            // Desktop file not available for this app => drop it!
+        UalWrapper::AppInfo appInfo = UalWrapper::getApplicationInfo(item->appId());
+        if (!appInfo.valid) {
+            // Application no longer available => drop it!
             toBeRemoved << item;
         } else if (!m_settings->storedApplications().contains(item->appId())) {
             // Item not in settings any more => drop it!
             toBeRemoved << item;
         } else {
             int idx = m_list.indexOf(item);
-            item->setName(desktopFile.displayName());
+            item->setName(appInfo.name);
             item->setPinned(item->pinned()); // update pinned text if needed
             item->setRunning(item->running());
             Q_EMIT dataChanged(index(idx), index(idx), {RoleName, RoleRunning});
 
             const QString oldIcon = item->icon();
-            if (oldIcon == desktopFile.icon()) { // same icon file, perhaps different contents, simulate changing the icon name to force reload
+            if (oldIcon == appInfo.icon) { // same icon file, perhaps different contents, simulate changing the icon name to force reload
                 item->setIcon(QString());
                 Q_EMIT dataChanged(index(idx), index(idx), {RoleIcon});
             }
 
             // now set the icon for real
-            item->setIcon(desktopFile.icon());
+            item->setIcon(appInfo.icon);
             Q_EMIT dataChanged(index(idx), index(idx), {RoleIcon});
         }
     }
@@ -452,15 +463,14 @@ void LauncherModel::refresh()
         if (itemIndex == -1) {
             // Need to add it. Just add it into the addedIndex to keep same ordering as the list
             // in the settings.
-            DesktopFileHandler desktopFile(entry);
-            if (!desktopFile.isValid()) {
-                qWarning() << "Couldn't find a .desktop file for" << entry << ". Skipping...";
+            UalWrapper::AppInfo appInfo = UalWrapper::getApplicationInfo(entry);
+            if (!appInfo.valid) {
                 continue;
             }
 
             LauncherItem *item = new LauncherItem(entry,
-                                                  desktopFile.displayName(),
-                                                  desktopFile.icon(),
+                                                  appInfo.name,
+                                                  appInfo.icon,
                                                   this);
             item->setPinned(true);
             beginInsertRows(QModelIndex(), addedIndex, addedIndex);
@@ -522,40 +532,61 @@ void LauncherModel::applicationAdded(const QModelIndex &parent, int row)
             item->setRecent(true);
             Q_EMIT dataChanged(index(itemIndex), index(itemIndex), {RoleRecent});
         }
-        if (item->surfaceCount() != app->surfaceCount()) {
-            item->setSurfaceCount(app->surfaceCount());
-            Q_EMIT dataChanged(index(itemIndex), index(itemIndex), {RoleSurfaceCount});
-        }
-
         item->setRunning(true);
     } else {
         LauncherItem *item = new LauncherItem(app->appId(), app->name(), app->icon().toString(), this);
         item->setRecent(true);
         item->setRunning(true);
         item->setFocused(app->focused());
-        item->setSurfaceCount(app->surfaceCount());
         beginInsertRows(QModelIndex(), m_list.count(), m_list.count());
         m_list.append(item);
         endInsertRows();
     }
-    connect(app, &ApplicationInfoInterface::surfaceCountChanged, this, &LauncherModel::applicationSurfaceCountChanged);
+    connect(app, &ApplicationInfoInterface::surfaceCountChanged, this, &LauncherModel::updateSurfaceList);
     m_asAdapter->syncItems(m_list);
     Q_EMIT dataChanged(index(itemIndex), index(itemIndex), {RoleRunning});
 }
 
-void LauncherModel::applicationSurfaceCountChanged(int count)
+void LauncherModel::updateSurfaceList()
 {
     ApplicationInfoInterface *app = static_cast<ApplicationInfoInterface*>(sender());
+    updateSurfaceListForApp(app);
+}
+
+void LauncherModel::updateSurfaceListForSurface()
+{
+    MirSurfaceInterface *iface = static_cast<MirSurfaceInterface*>(sender());
+    ApplicationInfoInterface* app = m_appManager->findApplication(iface->appId());
+    if (!app) {
+        return;
+    }
+    updateSurfaceListForApp(app);
+}
+
+void LauncherModel::updateSurfaceListForApp(ApplicationInfoInterface* app)
+{
     int idx = findApplication(app->appId());
     if (idx < 0) {
         qWarning() << "Received a surface count changed event from an app that's not in the Launcher model";
         return;
     }
     LauncherItem *item = m_list.at(idx);
-    if (item->surfaceCount() != count) {
-        item->setSurfaceCount(count);
-        Q_EMIT dataChanged(index(idx), index(idx), {RoleSurfaceCount});
+    QList<QPair<QString, QString> > surfaces;
+    for (int i = 0; i < app->surfaceList()->count(); ++i) {
+        MirSurfaceInterface* iface = app->surfaceList()->get(i);
+        if (iface->type() == Mir::NormalType || iface->type() == Mir::DialogType) {
+            // Avoid duplicate connections, so let's just disconnect first to be sure
+            disconnect(iface, &MirSurfaceInterface::nameChanged, this, &LauncherModel::updateSurfaceListForSurface);
+            connect(iface, &MirSurfaceInterface::nameChanged, this, &LauncherModel::updateSurfaceListForSurface);
+            QString name = iface->name();
+            if (name.isEmpty()) {
+                name = app->name();
+            }
+            surfaces.append({iface->persistentId(), name});
+        }
     }
+    item->setSurfaces(surfaces);
+    Q_EMIT dataChanged(index(idx), index(idx), {RoleSurfaceCount});
 }
 
 void LauncherModel::applicationRemoved(const QModelIndex &parent, int row)
@@ -576,7 +607,7 @@ void LauncherModel::applicationRemoved(const QModelIndex &parent, int row)
         return;
     }
 
-    disconnect(app, &ApplicationInfoInterface::surfaceCountChanged, this, &LauncherModel::applicationSurfaceCountChanged);
+    disconnect(app, &ApplicationInfoInterface::surfaceCountChanged, this, &LauncherModel::updateSurfaceList);
 
     LauncherItem * item = m_list.at(appIndex);
 
