@@ -1,5 +1,5 @@
 /*
- * Copyright 2013-2014 Canonical Ltd.
+ * Copyright 2013-2016 Canonical Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -12,14 +12,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *      Michael Zanetti <michael.zanetti@canonical.com>
  */
 
-#ifndef LAUNCHERMODEL_H
-#define LAUNCHERMODEL_H
+#pragma once
 
+#include <memory>
 #include <unity/shell/launcher/LauncherModelInterface.h>
 #include <unity/shell/application/ApplicationManagerInterface.h>
 
@@ -78,7 +75,9 @@ private Q_SLOTS:
     void applicationAdded(const QModelIndex &parent, int row);
     void applicationRemoved(const QModelIndex &parent, int row);
     void focusedAppIdChanged();
-    void applicationSurfaceCountChanged(int);
+    void updateSurfaceList();
+    void updateSurfaceListForApp(ApplicationInfoInterface *app);
+    void updateSurfaceListForSurface();
 
 private:
     QList<LauncherItem*> m_list;
@@ -91,5 +90,3 @@ private:
 
     friend class LauncherModelTest;
 };
-
-#endif // LAUNCHERMODEL_H
