@@ -18,6 +18,7 @@
 #include "dbusunitysessionservice.h"
 
 // system
+#include <grp.h>
 #include <sys/types.h>
 #include <unistd.h>
 #include <pwd.h>
@@ -211,6 +212,23 @@ public:
         QDBusConnection::SM_BUSNAME().asyncCall(msg);
     }
 
+    bool isUserInGroup(const QString &user, const QString &groupName) const
+    {
+        auto group = getgrnam(groupName.toUtf8().data());
+
+        if (group && group->gr_mem)
+        {
+            for (int i = 0; group->gr_mem[i]; ++i)
+            {
+                if (g_strcmp0(group->gr_mem[i], user.toUtf8().data()) == 0) {
+                    return true;
+                }
+            }
+        }
+
+        return false;
+    }
+
 private Q_SLOTS:
     void onPropertiesChanged(const QString &iface, const QVariantMap &changedProps, const QStringList &invalidatedProps)
     {
@@ -297,7 +315,13 @@ bool DBusUnitySessionService::CanShutdown() const
 
 bool DBusUnitySessionService::CanLock() const
 {
-    return true; // FIXME
+    auto user = UserName();
+    if (user.startsWith(QStringLiteral("guest-")) ||
+        d->isUserInGroup(user, QStringLiteral("nopasswdlogin"))) {
+        return false;
+    } else {
+        return true;
+    }
 }
 
 QString DBusUnitySessionService::UserName() const
@@ -335,8 +359,10 @@ void DBusUnitySessionService::PromptLock()
     // Prompt as in quick.  No locking animation needed.  Usually used by
     // indicator-session in combination with a switch to greeter or other
     // user session.
-    Q_EMIT LockRequested();
-    Q_EMIT lockRequested();
+    if (CanLock()) {
+        Q_EMIT LockRequested();
+        Q_EMIT lockRequested();
+    }
 }
 
 void DBusUnitySessionService::Lock()
@@ -468,11 +494,56 @@ void performAsyncUnityCall(const QString &method)
 
 
 DBusGnomeSessionManagerWrapper::DBusGnomeSessionManagerWrapper()
+    : UnityDBusObject(QStringLiteral("/org/gnome/SessionManager"), QStringLiteral("org.gnome.SessionManager"))
+{
+}
+
+void DBusGnomeSessionManagerWrapper::Logout(quint32 mode)
+{
+    auto call = QStringLiteral("RequestLogout");
+
+    // These modes are documented as bitwise flags, not an enum, even though
+    // they only ever seem to be used as enums.
+
+    if (mode & 1) // without dialog
+        call = QStringLiteral("Logout");
+    if (mode & 2) // without dialog, ignoring inhibitors (which we don't have)
+        call = QStringLiteral("Logout");
+
+    performAsyncUnityCall(call);
+}
+
+void DBusGnomeSessionManagerWrapper::Reboot()
+{
+    // GNOME's Reboot means with dialog (they use Request differently than us).
+    performAsyncUnityCall(QStringLiteral("RequestReboot"));
+}
+
+void DBusGnomeSessionManagerWrapper::RequestReboot()
+{
+    // GNOME's RequestReboot means no dialog (they use Request differently than us).
+    performAsyncUnityCall(QStringLiteral("Reboot"));
+}
+
+void DBusGnomeSessionManagerWrapper::RequestShutdown()
+{
+    // GNOME's RequestShutdown means no dialog (they use Request differently than us).
+    performAsyncUnityCall(QStringLiteral("Shutdown"));
+}
+
+void DBusGnomeSessionManagerWrapper::Shutdown()
+{
+    // GNOME's Shutdown means with dialog (they use Request differently than us).
+    performAsyncUnityCall(QStringLiteral("RequestShutdown"));
+}
+
+
+DBusGnomeSessionManagerDialogWrapper::DBusGnomeSessionManagerDialogWrapper()
     : UnityDBusObject(QStringLiteral("/org/gnome/SessionManager/EndSessionDialog"), QStringLiteral("com.canonical.Unity"))
 {
 }
 
-void DBusGnomeSessionManagerWrapper::Open(const unsigned type, const unsigned arg_1, const unsigned max_wait, const QList<QDBusObjectPath> &inhibitors)
+void DBusGnomeSessionManagerDialogWrapper::Open(const unsigned type, const unsigned arg_1, const unsigned max_wait, const QList<QDBusObjectPath> &inhibitors)
 {
     Q_UNUSED(arg_1);
     Q_UNUSED(max_wait);
