@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016 Canonical, Ltd.
+ * Copyright (C) 2016-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,13 +16,20 @@
 
 #include "WindowManagerPlugin.h"
 
-#include "TopLevelSurfaceList.h"
+#include "AvailableDesktopArea.h"
+#include "TopLevelWindowModel.h"
+#include "Window.h"
+#include "WindowMargins.h"
 
 #include <QtQml>
 
 void WindowManagerPlugin::registerTypes(const char *uri)
 {
-    qmlRegisterType<TopLevelSurfaceList>(uri, 0, 1, "TopLevelSurfaceList");
+    qmlRegisterType<AvailableDesktopArea>(uri, 1, 0, "AvailableDesktopArea");
+    qmlRegisterType<TopLevelWindowModel>(uri, 1, 0, "TopLevelWindowModel");
+    qmlRegisterType<WindowMargins>(uri, 1, 0, "WindowMargins");
+
+    qRegisterMetaType<Window*>("Window*");
 
     qRegisterMetaType<QAbstractListModel*>("QAbstractListModel*");
 }
