@@ -27,6 +27,9 @@ GSettingsControllerQml::GSettingsControllerQml()
     , m_autohideLauncher(false)
     , m_launcherWidth(8)
     , m_edgeDragWidth(2)
+    , m_enableLauncher(true)
+    , m_enableIndicatorMenu(true)
+    , m_appstoreUri("http://uappexplorer.com")
 {
 }
 
@@ -145,6 +148,37 @@ void GSettingsControllerQml::setEdgeDragWidth(uint edgeDragWidth)
     }
 }
 
+void GSettingsControllerQml::setEnableLauncher(bool enableLauncher)
+{
+    if (m_enableLauncher != enableLauncher) {
+        m_enableLauncher = enableLauncher;
+        Q_EMIT enableLauncherChanged(enableLauncher);
+    }
+}
+
+bool GSettingsControllerQml::enableLauncher() const
+{
+    return m_enableLauncher;
+}
+
+bool GSettingsControllerQml::enableIndicatorMenu() const
+{
+    return m_enableIndicatorMenu;
+}
+
+void GSettingsControllerQml::setEnableIndicatorMenu(bool enableIndicatorMenu)
+{
+    if (m_enableIndicatorMenu != enableIndicatorMenu) {
+        m_enableIndicatorMenu = enableIndicatorMenu;
+        Q_EMIT enableIndicatorMenuChanged(enableIndicatorMenu);
+    }
+}
+
+QString GSettingsControllerQml::appstoreUri() const
+{
+    return m_appstoreUri;
+}
+
 GSettingsSchemaQml::GSettingsSchemaQml(QObject *parent): QObject(parent) {
 }
 
@@ -209,6 +243,10 @@ void GSettingsQml::componentComplete()
             this, &GSettingsQml::launcherWidthChanged);
     connect(GSettingsControllerQml::instance(), &GSettingsControllerQml::edgeDragWidthChanged,
             this, &GSettingsQml::edgeDragWidthChanged);
+    connect(GSettingsControllerQml::instance(), &GSettingsControllerQml::enableLauncherChanged,
+            this, &GSettingsQml::enableLauncherChanged);
+    connect(GSettingsControllerQml::instance(), &GSettingsControllerQml::enableIndicatorMenuChanged,
+            this, &GSettingsQml::enableIndicatorMenuChanged);
 
     Q_EMIT disableHeightChanged();
     Q_EMIT pictureUriChanged();
@@ -218,6 +256,8 @@ void GSettingsQml::componentComplete()
     Q_EMIT autohideLauncherChanged();
     Q_EMIT launcherWidthChanged();
     Q_EMIT edgeDragWidthChanged();
+    Q_EMIT enableLauncherChanged();
+    Q_EMIT enableIndicatorMenuChanged();
 }
 
 GSettingsSchemaQml * GSettingsQml::schema() const {
@@ -324,6 +364,32 @@ QVariant GSettingsQml::edgeDragWidth() const
     }
 }
 
+QVariant GSettingsQml::enableLauncher() const
+{
+    if (m_valid && m_schema->id() == "com.canonical.Unity8") {
+        return GSettingsControllerQml::instance()->enableLauncher();
+    } else {
+        return QVariant();
+    }
+}
+
+QVariant GSettingsQml::enableIndicatorMenu() const
+{
+    if (m_valid && m_schema->id() == "com.canonical.Unity8") {
+        return GSettingsControllerQml::instance()->enableIndicatorMenu();
+    } else {
+        return QVariant();
+    }
+}
+
+QVariant GSettingsQml::appstoreUri() const
+{
+    if (m_valid && m_schema->id() == "com.canonical.Unity8") {
+        return GSettingsControllerQml::instance()->appstoreUri();
+    }
+    return QVariant();
+}
+
 void GSettingsQml::setLifecycleExemptAppids(const QVariant &appIds)
 {
     if (m_valid && m_schema->id() == "com.canonical.qtmir") {
@@ -351,3 +417,17 @@ void GSettingsQml::setEdgeDragWidth(const QVariant &edgeDragWidth)
         GSettingsControllerQml::instance()->setEdgeDragWidth(edgeDragWidth.toUInt());
     }
 }
+
+void GSettingsQml::setEnableLauncher(const QVariant &enableLauncher)
+{
+    if (m_valid && m_schema->id() == "com.canonical.Unity8") {
+        GSettingsControllerQml::instance()->setEnableLauncher(enableLauncher.toBool());
+    }
+}
+
+void GSettingsQml::setEnableIndicatorMenu(const QVariant &enableIndicatorMenu)
+{
+    if (m_valid && m_schema->id() == "com.canonical.Unity8") {
+        GSettingsControllerQml::instance()->setEnableIndicatorMenu(enableIndicatorMenu.toBool());
+    }
+}
