@@ -17,15 +17,19 @@
  */
 
 #include "plugin.h"
-#include "audio.h"
+#include "mediaplayer.h"
 #include "declarativeplaylist.h"
+#include "videooutput.h"
 
 #include <QtQml/qqml.h>
 
 void MockQtMultimediaPlugin::registerTypes(const char *uri)
 {
     Q_ASSERT(uri == QLatin1String("QtMultimedia"));
-    qmlRegisterType<Audio>(uri, 5, 0, "Audio");
-    qmlRegisterType<Audio>(uri, 5, 0, "MediaPlayer");
+    qmlRegisterType<MediaPlayer>(uri, 5, 0, "Audio");
+    qmlRegisterType<MediaPlayer>(uri, 5, 0, "MediaPlayer");
+    qmlRegisterType<VideoOutput>(uri, 5, 0, "VideoOutput");
+
+    qmlRegisterType<MediaDataSource>(uri, 5, 0, "MediaDataSource");
     qmlRegisterType<DeclarativePlaylist>(uri, 5, 6, "Playlist");
 }
