@@ -29,6 +29,7 @@ class MirSurface;
 
 #include <QList>
 #include <QTimer>
+#include <QUrl>
 
 using namespace unity::shell::application;
 
@@ -51,11 +52,14 @@ public:
     ApplicationInfo(const QString &appId, QObject *parent = nullptr);
     ~ApplicationInfo();
 
+    Q_INVOKABLE void createPromptSurface();
+
     RequestedState requestedState() const override;
     void setRequestedState(RequestedState) override;
 
     void setIconId(const QString &iconId);
     void setScreenshotId(const QString &screenshotId);
+    void setQmlFilename(const QString &);
 
     void setAppId(const QString &value) { m_appId = value; }
     QString appId() const override { return m_appId; }
@@ -108,11 +112,9 @@ public:
     MirSurfaceListInterface* promptSurfaceList() const override { return m_promptSurfaceList; }
     int surfaceCount() const override { return m_surfaceList->count(); }
 
-    void setFocused(bool value);
-
     //////
     // internal mock stuff
-    void close();
+    void close() override;
     void requestFocus();
 
 Q_SIGNALS:
@@ -152,6 +154,7 @@ private:
     QList<MirSurface*> m_closingSurfaces;
     bool m_manualSurfaceCreation{false};
     Mir::ShellChrome m_shellChrome{Mir::NormalChrome};
+    QUrl m_qmlFilePath;
 };
 
 Q_DECLARE_METATYPE(ApplicationInfo*)
