@@ -59,10 +59,14 @@ MirSurfaceItem::MirSurfaceItem(QQuickItem *parent)
         Qt::ExtraButton12 | Qt::ExtraButton13);
 
     connect(this, &QQuickItem::activeFocusChanged, this, &MirSurfaceItem::updateMirSurfaceActiveFocus);
-    connect(this, &QQuickItem::visibleChanged, this, &MirSurfaceItem::updateMirSurfaceVisibility);
+    connect(this, &QQuickItem::visibleChanged, this, &MirSurfaceItem::updateMirSurfaceExposure);
+
     connect(this, &MirSurfaceItem::consumesInputChanged, this, [this]() {
         updateMirSurfaceActiveFocus(hasActiveFocus());
     });
+
+    // We're just clipping contents in the mock. The real QtMir would copy only relevant buffer instead
+    setClip(true);
 }
 
 MirSurfaceItem::~MirSurfaceItem()
@@ -155,7 +159,9 @@ void MirSurfaceItem::setOrientationAngle(Mir::OrientationAngle angle)
 
     if (m_qmlItem) {
         QQmlProperty orientationProp(m_qmlItem, "orientationAngle");
-        orientationProp.write(QVariant::fromValue(orientationAngle()));
+        if (orientationProp.isValid()) {
+            orientationProp.write(QVariant::fromValue(orientationAngle()));
+        }
     }
 }
 
@@ -163,7 +169,9 @@ void MirSurfaceItem::updateScreenshot(QUrl screenshotUrl)
 {
     if (m_qmlItem) {
         QQmlProperty screenshotSource(m_qmlItem, "screenshotSource");
-        screenshotSource.write(QVariant::fromValue(screenshotUrl));
+        if (screenshotSource.isValid()) {
+            screenshotSource.write(QVariant::fromValue(screenshotUrl));
+        }
     }
 }
 
@@ -181,17 +189,31 @@ void MirSurfaceItem::createQmlContentItem()
     m_qmlItem = qobject_cast<QQuickItem*>(m_qmlContentComponent->create());
     m_qmlItem->setParentItem(this);
 
+    m_qmlItem->setWidth(m_surfaceWidth);
+    m_qmlItem->setHeight(m_surfaceHeight);
+
     setImplicitWidth(m_qmlItem->implicitWidth());
     setImplicitHeight(m_qmlItem->implicitHeight());
 
     {
         QQmlProperty screenshotSource(m_qmlItem, "screenshotSource");
-        screenshotSource.write(QVariant::fromValue(m_qmlSurface->screenshotUrl()));
+        if (screenshotSource.isValid()) {
+            screenshotSource.write(QVariant::fromValue(m_qmlSurface->screenshotUrl()));
+        }
     }
 
     {
         QQmlProperty orientationProp(m_qmlItem, "orientationAngle");
-        orientationProp.write(QVariant::fromValue(orientationAngle()));
+        if (orientationProp.isValid()) {
+            orientationProp.write(QVariant::fromValue(orientationAngle()));
+        }
+    }
+
+    {
+        QQmlProperty surfaceProperty(m_qmlItem, "surface");
+        if (surfaceProperty.isValid()) {
+            surfaceProperty.write(QVariant::fromValue(m_qmlSurface));
+        }
     }
 }
 
@@ -209,7 +231,7 @@ void MirSurfaceItem::touchEvent(QTouchEvent * event)
         Q_EMIT touchReleaseCountChanged(m_touchReleaseCount);
     }
 
-    Q_FOREACH(QTouchEvent::TouchPoint touchPoint, event->touchPoints()) {
+    Q_FOREACH(const QTouchEvent::TouchPoint &touchPoint, event->touchPoints()) {
         QString id(touchPoint.id());
         QVariantList list =  m_touchTrail[id].toList();
         list.append(QVariant::fromValue(touchPoint.pos()));
@@ -271,7 +293,7 @@ void MirSurfaceItem::setSurface(MirSurfaceInterface* surface)
         m_qmlSurface->registerView((qintptr)this);
 
         updateSurfaceSize();
-        updateMirSurfaceVisibility();
+        updateMirSurfaceExposure();
 
         if (m_orientationAngle) {
             m_qmlSurface->setOrientationAngle(*m_orientationAngle);
@@ -328,11 +350,11 @@ void MirSurfaceItem::updateMirSurfaceActiveFocus(bool focused)
     }
 }
 
-void MirSurfaceItem::updateMirSurfaceVisibility()
+void MirSurfaceItem::updateMirSurfaceExposure()
 {
     if (!m_qmlSurface) return;
 
-    m_qmlSurface->setViewVisibility((qintptr)this, isVisible());
+    m_qmlSurface->setViewExposure((qintptr)this, isVisible());
 }
 
 void MirSurfaceItem::setConsumesInput(bool value)
@@ -350,6 +372,7 @@ int MirSurfaceItem::surfaceWidth() const
 
 void MirSurfaceItem::setSurfaceWidth(int value)
 {
+//    qDebug() << "setSurfaceWidth called" << value;
     if (value != -1 && m_surfaceWidth != value) {
         m_surfaceWidth = value;
         Q_EMIT surfaceWidthChanged(m_surfaceWidth);
@@ -375,6 +398,11 @@ void MirSurfaceItem::updateSurfaceSize()
 {
     if (m_qmlSurface && m_surfaceWidth > 0 && m_surfaceHeight > 0) {
         m_qmlSurface->resize(m_surfaceWidth, m_surfaceHeight);
+        if (m_qmlItem) {
+            m_qmlItem->setWidth(m_surfaceWidth);
+            m_qmlItem->setHeight(m_surfaceHeight);
+        }
+        setImplicitSize(m_surfaceWidth, m_surfaceHeight);
     }
 }
 
