@@ -24,10 +24,11 @@
 
 VirtualKeyboard::VirtualKeyboard()
     : MirSurface("input-method",
-                     Mir::InputMethodType,
-                     Mir::MinimizedState,
-                     QUrl("qrc:///Unity/Application/vkb_portrait.png"),
-                     QUrl("qrc:///Unity/Application/VirtualKeyboard.qml"))
+                 Mir::InputMethodType,
+                 Mir::MinimizedState,
+                 nullptr, /* parentSurface */
+                 QUrl("qrc:///Unity/Application/vkb_portrait.png"),
+                 QUrl("qrc:///Unity/Application/VirtualKeyboard.qml"))
 {
 }
 
@@ -39,13 +40,15 @@ void VirtualKeyboard::updateInputBoundsAfterResize()
 {
     int width = this->width();
 
-    int height;
-    if (this->width() > this->height()) {
-        // landscape
-        height = this->height() * 0.4;
-    } else {
-        // portrait
-        height = this->width() * 0.6;
+    int height = 0;
+    if (visible()) {
+        if (this->width() > this->height()) {
+            // landscape
+            height = this->height() * 0.4;
+        } else {
+            // portrait
+            height = this->width() * 0.6;
+        }
     }
 
     int x = 0;
