@@ -17,6 +17,7 @@
 #include "plugin.h"
 #include "ApplicationInfo.h"
 #include "ApplicationManager.h"
+#include "MirMock.h"
 #include "MirSurfaceItem.h"
 #include "SurfaceManager.h"
 
@@ -28,36 +29,15 @@
 
 namespace {
 
-// Creates the singletons that are called throughout C++ code
-void createUnityApplicationSharedSingletons()
-{
-    // they have to be created in a specific order
-    if (!MirFocusController::instance()) {
-        new MirFocusController;
-    }
-    if (!SurfaceManager::instance()) {
-        new SurfaceManager;
-    }
-}
-
 QObject* applicationManagerSingleton(QQmlEngine*, QJSEngine*)
 {
-    createUnityApplicationSharedSingletons();
     return new ApplicationManager;
 }
 
-QObject* surfaceManagerSingleton(QQmlEngine*, QJSEngine*)
+QObject* mirSingleton(QQmlEngine*, QJSEngine*)
 {
-    createUnityApplicationSharedSingletons();
-    return SurfaceManager::instance();
+    return new MirMock;
 }
-
-QObject* mirFocusControllerSingleton(QQmlEngine*, QJSEngine*)
-{
-    createUnityApplicationSharedSingletons();
-    return MirFocusController::instance();
-}
-
 } // anonymous namespace
 
 void FakeUnityApplicationQmlPlugin::registerTypes(const char *uri)
@@ -65,6 +45,7 @@ void FakeUnityApplicationQmlPlugin::registerTypes(const char *uri)
     qRegisterMetaType<ApplicationInfo*>("ApplicationInfo*");
     qRegisterMetaType<unity::shell::application::MirSurfaceInterface*>("unity::shell::application::MirSurfaceInterface*");
     qRegisterMetaType<unity::shell::application::MirSurfaceListInterface*>("unity::shell::application::MirSurfaceListInterface*");
+    qRegisterMetaType<unity::shell::application::SurfaceManagerInterface*>("unity::shell::application::SurfaceManagerInterface*");
     qRegisterMetaType<Mir::Type>("Mir::Type");
     qRegisterMetaType<Mir::State>("Mir::State");
 
@@ -73,14 +54,12 @@ void FakeUnityApplicationQmlPlugin::registerTypes(const char *uri)
     qmlRegisterUncreatableType<MirSurface>(uri, 0, 1, "MirSurface", "MirSurface can't be instantiated from QML");
     qmlRegisterUncreatableType<unity::shell::application::MirSurfaceInterface>(
                     uri, 0, 1, "MirSurface", "MirSurface can't be instantiated from QML");
-    qmlRegisterSingletonType<MirFocusController>(uri, 0, 1, "MirFocusController", mirFocusControllerSingleton);
     qmlRegisterType<MirSurfaceItem>(uri, 0, 1, "MirSurfaceItem");
     qmlRegisterType<ApplicationInfo>(uri, 0, 1, "ApplicationInfo");
 
     qmlRegisterSingletonType<ApplicationManager>(uri, 0, 1, "ApplicationManager", applicationManagerSingleton);
-    qmlRegisterSingletonType<SurfaceManager>(uri, 0, 1, "SurfaceManager", surfaceManagerSingleton);
-
-    qmlRegisterUncreatableType<Mir>(uri, 0, 1, "Mir", "Mir provides enum values, it can't be instantiated");
+    qmlRegisterSingletonType<MirMock>(uri, 0, 1, "Mir", mirSingleton);
+    qmlRegisterType<SurfaceManager>(uri, 0, 1, "SurfaceManager");
 }
 
 void FakeUnityApplicationQmlPlugin::initializeEngine(QQmlEngine *engine, const char *uri)
