@@ -1,3 +1,19 @@
+/*
+ * Copyright (C) 2017 Canonical, Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 var usageScenario = (typeof shell != 'undefined') ? shell.usageScenario : "desktop";
 
 var fakeMenuData = {
@@ -30,7 +46,7 @@ var fakeMenuData = {
                         "type": "com.canonical.indicator.messages.messageitem",
                         "ext": {
                                 "icon": "file:///usr/share/ubuntu/settings/system/icons/settings-system-update.svg",
-                                "xCanonicalAppIcon": "file:///usr/share/ubuntu/settings/system/system-settings.png",
+                                "xCanonicalAppIcon": "image://theme/system-settings",
                                 "xCanonicalMessageActions": null,
                                 "xCanonicalText": "Tap to open the system updater.",
                                 "xCanonicalTime": ((new Date).getTime() - 350 * 1000) * 1000,
@@ -47,12 +63,12 @@ var fakeMenuData = {
                         "action": "indicator.telephony-service-sms.msg.MSG_ID",
                         "actionState": {},
                         "ext": {},
-                        "icon": "file:///usr/share/telephony-service/assets/avatar-default@18.png",
+                        "icon": Qt.resolvedUrl("../../../../../tests/graphics/avatars/funky@12.png"),
                         "type": "com.canonical.indicator.messages.messageitem",
                         "ext": {
-                            "icon": "file:///usr/share/telephony-service/assets/avatar-default@18.png",
-                            "xCanonicalAppIcon": "image://theme/telephony-service-message",
-                            "xCanonicalMessageActions": "",
+                            "icon": Qt.resolvedUrl("../../../../../tests/graphics/avatars/funky@12.png"),
+                            "xCanonicalAppIcon": Qt.resolvedUrl("../../../../../tests/graphics/applicationIcons/messages-app@18.png"),
+                            "xCanonicalMessageActions": [ { "parameter-type": "s" } ],
                             "xCanonicalText": "This is a message sent to an awesome Ubuntu phone.",
                             "xCanonicalTime": ((new Date).getTime() - 35 * 1000) * 1000
                         },
@@ -64,6 +80,25 @@ var fakeMenuData = {
                         "sensitive": true
                     }
                 },
+                {
+                    "rowData": {
+                        "label": "+39441234567 - [SIM 2]",
+                        "sensitive": true,
+                        "isSeparator": false,
+                        "icon": "image://theme/missed-call",
+                        "type": "com.canonical.indicator.messages.messageitem",
+                        "ext": {
+                                "xCanonicalMessageActions": [ { "parameter-type": "_s" } ],
+                                "xCanonicalText": "1 Missed call.",
+                                "xCanonicalTime": ((new Date).getTime() - 350 * 1000) * 1000,
+                        },
+                        "action": "indicator.telephony-service-missed-call.call.CALL_ID",
+                        "actionState": {},
+                        "isCheck": false,
+                        "isRadio": false,
+                        "isToggled": false,
+                    }
+                },
                 {
                     "rowData": {
                         "action": "indicator.remove-all",
@@ -337,34 +372,72 @@ var fakeMenuData = {
                 "type": "com.canonical.indicator.root"
             },
             "submenu": [
-                {
+                    {
+                        "rowData": {
+                            "label": "Charge Level",
+                            "sensitive": false,
+                            "isSeparator": false,
+                            "icon": "",
+                            "type": "com.canonical.indicator.progress",
+                            "ext": {},
+                            "action": "indicator.battery-level",
+                            "actionState": "100",
+                            "isCheck": false,
+                            "isRadio": false,
+                            "isToggled": false
+                        }
+                    },
+                    {
+
+                        "rowData": {
+                            "label": "",
+                            "sensitive": true,
+                            "isSeparator": true,
+                            "icon": "",
+                            "type": "",
+                            "ext": {},
+                            "action": "",
+                            "actionState": "",
+                            "isCheck": false,
+                            "isRadio": false,
+                            "isToggled": false
+                        }
+                    },
+                    {
+
+                        "rowData": {
+                            "label": "",
+                            "sensitive": true,
+                            "isSeparator": false,
+                            "icon": "",
+                            "type": "com.canonical.unity.slider",
+                            "ext": {
+                                "maxIcon": "image://theme/display-brightness-max",
+                                "maxValue": "1",
+                                "minIcon": "image://theme/display-brightness-min",
+                                "minValue": "0",
+                            },
+                            "action": "indicator.brightness",
+                            "actionState": "0.212244897959184",
+                            "isCheck": false,
+                            "isRadio": false,
+                            "isToggled": false
+                        }
+                    },
+                    {
+
                     "rowData": {
-                        "action": "indicator.activate-statistics",
-                        "actionState": {},
-                        "ext": {},
-                        "icon": "image://theme/battery-full-charged-symbolic",
-                        "isCheck": false,
-                        "isRadio": false,
-                        "isSeparator": false,
-                        "isToggled": false,
-                        "label": "Battery (full charged)",
+                        "label": "Auto-brightness",
                         "sensitive": true,
-                        "type": "com.canonical.indicator.basic"
-                    }
-                },
-                {
-                    "rowData": {
-                        "action": "indicator.activate-statistics",
-                        "actionState": {},
-                        "ext": {},
-                        "icon": "image://theme/battery-100",
-                        "isCheck": false,
-                        "isRadio": false,
                         "isSeparator": false,
-                        "isToggled": false,
-                        "label": "Battery",
-                        "sensitive": true,
-                        "type": "com.canonical.indicator.basic"
+                        "icon": "",
+                        "type": "com.canonical.indicator.switch",
+                        "ext": {},
+                        "action": "indicator.auto-brightness",
+                        "actionState": false,
+                        "isCheck": true,
+                        "isRadio": false,
+                        "isToggled": false
                     }
                 },
                 {
@@ -510,7 +583,7 @@ var fakeMenuData = {
                             "state": "Stopped"
                         },
                         "ext": {},
-                        "icon": "file:///usr/share/mediaplayer-app/mediaplayer-app.png",
+                        "icon": "image://theme/mediaplayer-app",
                         "isCheck": false,
                         "isRadio": false,
                         "isSeparator": false,
@@ -555,7 +628,6 @@ var fakeMenuData = {
         }
     ],
 
-
    "fake-indicator-datetime": [
         {
             "rowData": {
@@ -591,6 +663,25 @@ var fakeMenuData = {
                         "type": ""
                     }
                 },
+                {
+                    "rowData": {
+                        "action": "indicator.calendar",
+                        "actionState": {
+                            "appointment-days": [10],
+                            "calendar-day": (new Date).getTime() / 1000,
+                            "show-week-numbers": false,
+                        },
+                        "ext": {},
+                        "icon": "image://theme/calendar",
+                        "isCheck": false,
+                        "isRadio": true,
+                        "isSeparator": false,
+                        "isToggled": false,
+                        "label": "[calendar]",
+                        "sensitive": true,
+                        "type": "com.canonical.indicator.calendar"
+                    }
+                },
                 {
                     "rowData": {
                         "action": "",
@@ -621,6 +712,23 @@ var fakeMenuData = {
                         "type": ""
                     }
                 },
+                {
+                    "rowData": {
+                        "action": "indicator.phone.open-appointment",
+                        "actionState": {},
+                        "ext": {
+                            "xCanonicalTime": (new Date).getTime() / 1000 + 55 * 60
+                        },
+                        "icon": "image://theme/alarm-clock",
+                        "isCheck": false,
+                        "isRadio": false,
+                        "isSeparator": false,
+                        "isToggled": false,
+                        "label": "Wake up!",
+                        "sensitive": true,
+                        "type": "com.canonical.indicator.alarm"
+                    }
+                },
                 {
                     "rowData": {
                         "action": "indicator.phone.open-appointment",
@@ -727,7 +835,6 @@ var fakeMenuData = {
         }
     ],
 
-
     "fake-indicator-files": [
         {
             "rowData": {
@@ -772,7 +879,7 @@ var fakeMenuData = {
                         "ext": {
                             "xCanonicalUid": 1003
                         },
-                        "icon": "file:///usr/share/webbrowser-app/webbrowser-app.png",
+                        "icon": "image://theme/webbrowser-app",
                         "isCheck": false,
                         "isRadio": false,
                         "isSeparator": false,
@@ -821,7 +928,7 @@ var fakeMenuData = {
                         "ext": {
                             "xCanonicalUid": 1002
                         },
-                        "icon": "file:///usr/share/webbrowser-app/webbrowser-app.png",
+                        "icon": "image://theme/webbrowser-app",
                         "isCheck": false,
                         "isRadio": false,
                         "isSeparator": false,
@@ -838,7 +945,7 @@ var fakeMenuData = {
                         "ext": {
                             "xCanonicalUid": 1001
                         },
-                        "icon": "file:///usr/share/webbrowser-app/webbrowser-app.png",
+                        "icon": "image://theme/webbrowser-app",
                         "isCheck": false,
                         "isRadio": false,
                         "isSeparator": false,
@@ -1102,5 +1209,119 @@ var fakeMenuData = {
                 }
             ]
         }
-    ]
+    ],
+
+    "indicator-keyboard": [
+        {
+            "rowData": {
+                "action": "indicator.indicator",
+                "actionState": {
+                    "icons": [],
+                    "label": "",
+                    "title": "English (USA, QWERTY)",
+                    "visible": true
+                },
+                "icon": "",
+                "isCheck": false,
+                "isRadio": false,
+                "isSeparator": false,
+                "isToggled": false,
+                "label": "",
+                "sensitive": true,
+                "type": "com.canonical.indicator.root"
+            },
+            "submenu": [
+                {
+                    "rowData": {
+                        "label": "České (QWERTY)",
+                        "sensitive": true,
+                        "isSeparator": false,
+                        "icon": "image://theme/indicator-keyboard-Cs",
+                        "type": "",
+                        "ext": {},
+                        "action": "indicator.current",
+                        "actionState": 0,
+                        "isCheck": false,
+                        "isRadio": true,
+                        "isToggled": false
+                    }
+                },
+                {
+                    "rowData": {
+                        "label": "Italiana (QWERTY)",
+                        "sensitive": true,
+                        "isSeparator": false,
+                        "icon": "image://theme/indicator-keyboard-It",
+                        "type": "",
+                        "ext": {},
+                        "action": "indicator.current",
+                        "actionState": 0,
+                        "isCheck": false,
+                        "isRadio": true,
+                        "isToggled": false
+                    }
+                },
+                {
+                    "rowData": {
+                        "label": "English (USA)",
+                        "sensitive": true,
+                        "isSeparator": false,
+                        "icon": "image://theme/indicator-keyboard-En",
+                        "type": "",
+                        "ext": {},
+                        "action": "indicator.current",
+                        "actionState": 0,
+                        "isCheck": false,
+                        "isRadio": true,
+                        "isToggled": true
+                    }
+                },
+                {
+                    "rowData": {
+                        "label": "",
+                        "sensitive": true,
+                        "isSeparator": true,
+                        "icon": "",
+                        "type": "",
+                        "ext": {},
+                        "action": "",
+                        "actionState": "",
+                        "isCheck": false,
+                        "isRadio": false,
+                        "isToggled": false
+                    }
+                },
+                {
+                    "rowData": {
+                        "label": "Character Map",
+                        "sensitive": true,
+                        "isSeparator": false,
+                        "icon": "",
+                        "type": "",
+                        "ext": {},
+                        "action": "indicator.map",
+                        "actionState": "",
+                        "isCheck": false,
+                        "isRadio": false,
+                        "isToggled": false
+                    }
+                },
+                {
+                    "rowData": {
+                        "label": "Keyboard layout",
+                        "sensitive": true,
+                        "isSeparator": false,
+                        "icon": "",
+                        "type": "",
+                        "ext": {},
+                        "action": "indicator.key-map.settings",
+                        "actionState": "",
+                        "isCheck": false,
+                        "isRadio": false,
+                        "isToggled": false
+                    }
+                }
+            ]
+        }
+    ],
 }
