@@ -37,6 +37,10 @@ QVariant MockQuickListModel::data(const QModelIndex &index, int role) const
         return QLatin1String("copy.png");
     case RoleClickable:
         return index.row() == 1 ? false : true;
+    case RoleHasSeparator:
+        return index.row() <= 1 ? true : false;
+    case RoleIsPrivate:
+        return index.row() == 4 ? true : false;
     }
     return QVariant();
 }
@@ -44,5 +48,5 @@ QVariant MockQuickListModel::data(const QModelIndex &index, int role) const
 int MockQuickListModel::rowCount(const QModelIndex &parent) const
 {
     Q_UNUSED(parent)
-    return 4;
+    return 5;
 }
