@@ -21,5 +21,5 @@ class UnityScreensPlugin : public QQmlExtensionPlugin {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface/1.0")
 public:
-    virtual void registerTypes(const char* uri);
+    void registerTypes(const char* uri) override;
 };
