@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2016 Canonical, Ltd.
+ * Copyright (C) 2015-2017 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,10 @@
 #include <inputeventgenerator.h>
 #include <deviceconfigparser.h>
 #include <globalfunctions.h>
+#include <appdrawerproxymodel.h>
+#include <tabfocusfence.h>
+#include <expressionfiltermodel.h>
+#include <quicklistproxymodel.h>
 
 static QObject *createWindowStateStorage(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
@@ -82,4 +86,8 @@ void FakeUtilsPlugin::registerTypes(const char *uri)
     qmlRegisterType<DeviceConfigParser>(uri, 0, 1, "DeviceConfigParser");
     qmlRegisterSingletonType<GlobalFunctions>(uri, 0, 1, "Functions", createGlobalFunctions);
     qmlRegisterType<URLDispatcher>(uri, 0, 1, "URLDispatcher");
+    qmlRegisterType<AppDrawerProxyModel>(uri, 0, 1, "AppDrawerProxyModel");
+    qmlRegisterType<TabFocusFenceItem>(uri, 0, 1, "TabFocusFence");
+    qmlRegisterType<ExpressionFilterModel>(uri, 0, 1, "ExpressionFilterModel");
+    qmlRegisterType<QuickListProxyModel>(uri, 0, 1, "QuickListProxyModel");
 }
