@@ -36,6 +36,7 @@ class UserMetricsPrivate;
 
 class Q_DECL_EXPORT UserMetricsData: public QObject
 {
+    Q_OBJECT
 public:
     explicit UserMetricsData(QObject *parent);
 
@@ -64,6 +65,7 @@ private:
 
 class UserMetricsPrivate: QObject
 {
+    Q_OBJECT
 public:
     explicit UserMetricsPrivate(UserMetrics *parent);
 
@@ -88,12 +90,16 @@ public:
     void setUsername(const QString &username);
 
 protected:
+    void findAndSetUsername(const QString &username);
+
     void nextFakeData();
 
     void generateFakeData();
 
     void loadFakeData();
 
+    void loadUserMetricsData();
+
     void finishSetFakeData();
 
 private:
@@ -102,6 +108,7 @@ private:
 
 class UserMetricsDataPrivate: QObject
 {
+    Q_OBJECT
 public:
     explicit UserMetricsDataPrivate(UserMetricsData *parent);
 
@@ -131,7 +138,7 @@ private:
 }
 
 UserMetricsDataPrivate::UserMetricsDataPrivate(UserMetricsData *parent) :
-        q_ptr(parent), m_firstColor(this), m_secondColor(this)
+        q_ptr(parent), m_label(""), m_firstColor(this), m_secondColor(this)
 {
     m_length = calculateLength();
 }
@@ -229,12 +236,8 @@ UserMetricsPrivate::~UserMetricsPrivate()
 {
 }
 
-void UserMetricsPrivate::setUsername(const QString &username)
+void UserMetricsPrivate::findAndSetUsername(const QString &username)
 {
-    if (m_username == username && m_newData) {
-        return;
-    }
-
     m_username = username;
 
     m_dataIndex = m_fakeData.constFind(m_username);
@@ -243,6 +246,16 @@ void UserMetricsPrivate::setUsername(const QString &username)
         m_dataIndex = m_fakeData.constFind("");
     }
 
+    m_newData = *m_dataIndex;
+}
+
+void UserMetricsPrivate::setUsername(const QString &username)
+{
+    if (m_username == username && m_newData) {
+        return;
+    }
+
+    findAndSetUsername(username);
     loadFakeData();
 
     q_ptr->usernameChanged(m_username);
@@ -332,7 +345,6 @@ void UserMetricsPrivate::generateFakeData()
 
 void UserMetricsPrivate::loadFakeData()
 {
-    m_newData = *m_dataIndex;
 
     bool oldLabelEmpty = m_label.isEmpty();
     bool newLabelEmpty = m_newData->label().isEmpty();
@@ -351,24 +363,28 @@ void UserMetricsPrivate::loadFakeData()
     // we emit no signal if the data has stayed empty
 }
 
-void UserMetricsPrivate::finishSetFakeData()
+void UserMetricsPrivate::loadUserMetricsData()
 {
-    bool oldLabelEmpty = m_label.isEmpty();
-    bool newLabelEmpty = m_newData->label().isEmpty();
-
     m_label = m_newData->label();
     m_firstColor = m_newData->firstColor();
     m_firstMonth.setVariantList(m_newData->firstMonth());
     m_secondColor = m_newData->secondColor();
     m_secondMonth.setVariantList(m_newData->secondMonth());
-
-    bool currentDayChanged = m_currentDay != m_newData->length();
     m_currentDay = m_newData->length();
+}
+
+void UserMetricsPrivate::finishSetFakeData()
+{
+    bool oldLabelEmpty = m_label.isEmpty();
+    bool newLabelEmpty = m_newData->label().isEmpty();
+    bool currentDayChanged = m_currentDay != m_newData->length();
+
+    loadUserMetricsData();
 
     q_ptr->labelChanged(m_label);
     if (currentDayChanged)
     {
-        q_ptr->currentDayChanged(m_currentDay);
+       q_ptr->currentDayChanged(m_currentDay);
     }
 
     if (oldLabelEmpty && !newLabelEmpty)
@@ -396,6 +412,7 @@ void UserMetricsPrivate::nextFakeData()
         }
     }
 
+    m_newData = *m_dataIndex;
     loadFakeData();
 }
 
@@ -464,6 +481,12 @@ void UserMetrics::readyForDataChangeSlot()
     d_ptr->finishSetFakeData();
 }
 
+void UserMetrics::reset()
+{
+    d_ptr->findAndSetUsername("");
+    d_ptr->loadUserMetricsData();
+}
+
 /**
  * Factory methods
  */
@@ -472,3 +495,5 @@ UserMetrics * UserMetrics::getInstance()
 {
     return new UserMetrics();
 }
+
+#include "UserMetrics.moc"
