@@ -27,7 +27,10 @@
 
 #include "horizontaljournal.h"
 
+#include <paths.h>
+
 class WidthModel : public QAbstractListModel {
+    Q_OBJECT
 public:
     QHash<int, QByteArray> roleNames() const override
     {
@@ -85,7 +88,7 @@ private:
     {
         QTRY_COMPARE(item->x(), x);
         QTRY_COMPARE(item->y(), y);
-        QTRY_COMPARE(item->width(), model->stringList()[modelIndex].toDouble());
+        QTRY_COMPARE(item->width(), model->stringList().at(modelIndex).toDouble());
         QTRY_COMPARE(QQuickItemPrivate::get(item)->culled, !visible);
     }
 
@@ -126,7 +129,7 @@ private Q_SLOTS:
         widthList << "100" << "50" << "125" << "10" << "40" << "70" << "200" << "110" << "160" << "20" << "20" << "65" << "80" << "200" << "300" << "130" << "400" << "300" << "500" << "10";
         model->setStringList(widthList);
 
-        view->setSource(QUrl::fromLocalFile(DASHVIEWSTEST_FOLDER "/horizontaljournaltest.qml"));
+        view->setSource(QUrl::fromLocalFile(testDataDir() + "/" TEST_DIR "/horizontaljournaltest.qml"));
 
         view->show();
         view->resize(470, 400);
