@@ -21,15 +21,14 @@
 #include <QQuickView>
 #include <QSignalSpy>
 #include <QtTestGui>
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-pedantic"
 #include <private/qqmllistmodel_p.h>
 #include <private/qquickanimation_p.h>
 #include <private/qquickitem_p.h>
-#pragma GCC diagnostic pop
 
 #include <limits>
 
+#include <paths.h>
+
 // TODO Think on how doing a test for lost items
 // particullary making sure that lost items are culled
 // and then removed in the next updatePolish cycle
@@ -45,6 +44,11 @@ private:
         QTRY_COMPARE(item->y(), pos);
         QTRY_COMPARE(item->height(), height);
         QCOMPARE(QQuickItemPrivate::get(item->m_item)->culled, culled);
+        if (lvwph->delegate() == otherDelegate) {
+            QCOMPARE(item->m_item->width(), lvwph->width());
+        } else {
+            QCOMPARE(item->m_item->width(), lvwph->width() - 20);
+        }
     }
 
     void changeContentY(qreal change)
@@ -119,8 +123,8 @@ private Q_SLOTS:
     void init()
     {
         view = new QQuickView();
-        view->setSource(QUrl::fromLocalFile(DASHVIEWSTEST_FOLDER "/listviewwithpageheadertest.qml"));
-        lvwph = dynamic_cast<ListViewWithPageHeader*>(view->rootObject()->findChild<QQuickFlickable*>());
+        view->setSource(QUrl::fromLocalFile(testDataDir() + "/" TEST_DIR "/listviewwithpageheadertest.qml"));
+        lvwph = static_cast<ListViewWithPageHeader*>(view->rootObject()->findChild<QQuickFlickable*>());
         model = view->rootObject()->findChild<QQmlListModel*>();
         otherDelegate = view->rootObject()->findChild<QQmlComponent*>();
         QVERIFY(lvwph);
@@ -1977,6 +1981,51 @@ private Q_SLOTS:
         verifyItem(0, 50., 200., false);
     }
 
+    void testBug1569976()
+    {
+        QMetaObject::invokeMethod(model, "removeItems", Q_ARG(QVariant, 3), Q_ARG(QVariant, 3));
+
+        for (int i = 0; i < 10; ++i) {
+            scrollToBottom();
+            lvwph->showHeader();
+            QTRY_VERIFY(!lvwph->m_contentYAnimation->isRunning());
+            scrollToTop();
+        }
+        verifyItem(0, 50., 150., false);
+        verifyItem(1, 200., 200., false);
+        verifyItem(2, 400., 350., false);
+    }
+
+    void testRemoveItemNotShowHeader()
+    {
+        QMetaObject::invokeMethod(model, "removeItems", Q_ARG(QVariant, 0), Q_ARG(QVariant, 6));
+        QMetaObject::invokeMethod(model, "insertItem", Q_ARG(QVariant, 0), Q_ARG(QVariant, 90));
+        QMetaObject::invokeMethod(model, "insertItem", Q_ARG(QVariant, 1), Q_ARG(QVariant, 600));
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 2);
+        scrollToBottom();
+        QMetaObject::invokeMethod(model, "insertItem", Q_ARG(QVariant, 1), Q_ARG(QVariant, 2000));
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 3);
+        QMetaObject::invokeMethod(model, "removeItems", Q_ARG(QVariant, 2), Q_ARG(QVariant, 1));
+        QTRY_COMPARE(lvwph->m_headerItem->y(), -610.);
+        QTRY_COMPARE(lvwph->m_minYExtent, 610.);
+    }
+
+    void testRemoveItemCutContents()
+    {
+        view->rootObject()->setHeight(921);
+        QMetaObject::invokeMethod(model, "removeItems", Q_ARG(QVariant, 0), Q_ARG(QVariant, 6));
+        QMetaObject::invokeMethod(model, "insertItem", Q_ARG(QVariant, 0), Q_ARG(QVariant, 1000));
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 1);
+        QTRY_COMPARE(lvwph->contentHeight(), 1050.);
+        scrollToBottom();
+        QMetaObject::invokeMethod(model, "insertItem", Q_ARG(QVariant, 0), Q_ARG(QVariant, 530));
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 2);
+        QMetaObject::invokeMethod(model, "removeItems", Q_ARG(QVariant, 1), Q_ARG(QVariant, 1));
+        QTRY_COMPARE(lvwph->m_visibleItems.count(), 1);
+        verifyItem(0, 50., 530., false);
+        QTRY_COMPARE(lvwph->m_minYExtent, 530.);
+    }
+
 private:
     QQuickView *view;
     ListViewWithPageHeader *lvwph;
