@@ -23,14 +23,14 @@
 #include <QStringListModel>
 #include <QQmlContext>
 #include <QQmlEngine>
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-pedantic"
 #include <private/qquickitem_p.h>
-#pragma GCC diagnostic pop
 
 #include "organicgrid.h"
 
+#include <paths.h>
+
 class DummyModel : public QAbstractListModel {
+    Q_OBJECT
 public:
     DummyModel() : m_count(0) {}
 
@@ -130,13 +130,13 @@ private Q_SLOTS:
         model = new DummyModel();
         model->setCount(21);
 
-        view->setSource(QUrl::fromLocalFile(DASHVIEWSTEST_FOLDER "/organicgridtest.qml"));
+        view->setSource(QUrl::fromLocalFile(testDataDir() + "/" TEST_DIR "/organicgridtest.qml"));
 
         view->show();
         QTest::qWaitForWindowExposed(view);
         view->resize(470, 400);
 
-        grid = dynamic_cast<OrganicGrid*>(view->rootObject()->findChild<QObject*>("grid"));
+        grid = static_cast<OrganicGrid*>(view->rootObject()->findChild<QObject*>("grid"));
         grid->setModel(model);
         QTRY_COMPARE(grid->width(), 470.);
 
